@@ -1,4 +1,5 @@
-"""
+# encoding: utf-8
+'''
 WaitpidMonitor -- Thread that runs (blocking) waitpid on a process.
                   Can be used to simulate waitpid with timeout.
 
@@ -11,7 +12,11 @@ License, v. 2.0. If a copy of the MPL was not distributed with this
 file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 @contact:    choller@mozilla.com
-"""
+'''
+
+# Ensure print() compatibility with Python 3
+from __future__ import print_function
+
 import os
 import threading
 
